@@ -2,13 +2,13 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : chinese_name_processor.py
 @Created : 2018-00-00
-@Updated : 2020-08-09
+@Updated : 2020-09-10
 @Version : 1.4.18
 @Desc    :
 """
 import re
+from typing import *
 
-from ._typings import *
 from .read_and_write import read_file_by_line, read_json
 from .tree_and_trie import Trie
 
@@ -374,7 +374,7 @@ class PinyinProcessor:
                 *self.pinyin_patterns_4_name['single'],
                 *self.pinyin_patterns_4_name['double'],
             ]
-
+    
     # --------------------------------------------------------------------------
     # pinyin patterns
     
@@ -432,7 +432,7 @@ class PinyinProcessor:
             return lastname in self.pinyin_patterns['pinyin+wade']
         else:
             return lastname in self.pinyin_patterns['pinyin']
-
+    
     # --------------------------------------------------------------------------
     # tries
     
