@@ -2,19 +2,19 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : data_convert.py
 @Created : 2018-00-00
-@Updated : 2020-08-09
-@Version : 3.0.1
+@Updated : 2020-09-06
+@Version : 3.0.2
 @Desc    : Convert source file type to target file type.
 """
 import re
 
 from bs4 import BeautifulSoup
 from bs4.element import Tag
+from lk_logger import lk
 
 from . import exit_ways
 from .excel_reader import ExcelReader
 from .excel_writer import ExcelWriter
-from .lk_logger import lk
 from .read_and_write import read_file, write_file
 
 
@@ -59,8 +59,8 @@ def excel_2_json(ifile='../temp/in.xlsx', ofile='../temp/out.json',
     :param ifile
     :param ofile
     :param key: 主键依据. 默认是行号, 因为行号是不重复的, 适合作为字典的键. 您也
-     可以定义表格中的某个字段为主键. 另外, 如果 key 设为空字符串, 则以列表形式输
-     出每一行.
+        可以定义表格中的某个字段为主键. 另外, 如果 key 设为空字符串, 则以列表形
+        式输出每一行.
     """
     from .excel_reader import ExcelReader
     from .read_and_write import write_json
@@ -104,7 +104,7 @@ def excel_2_json_kv(ifile='../temp/in.xlsx', ofile='../temp/out.json',
                     header=False):
     """ 将 excel 转换为 json 文件.
     要求 excel 只有两列数据 (占据第一, 第二列位置), 且目标数据位于 sheet 1. 最后
-     转换的结果是以第一列为 keys, 第二列为 values.
+    转换的结果是以第一列为 keys, 第二列为 values.
     """
     from .excel_reader import ExcelReader
     from .read_and_write import write_json
@@ -145,8 +145,8 @@ def pdf_2_txt(ifile: str, ofile: str, page_start=0, page_end=0, dump_images=''):
     laparams = layout.LAParams()
     image_writer = ImageWriter(dump_images) if dump_images else None
     # NOTE: 我对 pdfminer.image 的源码 ($VENV$\Lib\site-packages\pdfminer\image.
-    #  py) 进行了修改, 增加了 self.picno 变量以避免导出时的图片名重复, 详见源码
-    #  中的 "LKDO" 标记.
+    #   py) 进行了修改, 增加了 self.picno 变量以避免导出时的图片名重复, 详见源码
+    #   中的 "LKDO" 标记.
     
     reader = open(ifile, 'rb')
     writer = open(ofile, 'w', encoding='utf-8')
@@ -260,7 +260,7 @@ def excel_2_html(ifile, ofile, title='', dialog=False):
             1. 链接必须以 'http' 或 'https' 开头
             2. 单个单元格必须有且只有一个链接 (如果有多个, 则不作处理)
             3. 链接所属的标题头必须含 "|" 符号, 您可以使用 "homepage|", 本脚本会
-            使用一个默认值: "visit"
+               使用一个默认值: "visit"
     """
     
     reader = ExcelReader(ifile)
@@ -412,7 +412,7 @@ def html_2_excel(ifile, ofile, single_sheet=True):
         1. 源网页的标签名大小写是否规范 (本函数只支持正确的大小写)
         2. 源网页的表格是否是 <p> 组成的 (如果是则本函数不支持)
         3. 如果源网页格式错乱, 可以尝试先用 chrome 打开, 再从开发者工具中复制网
-        页 html (该 html 是经过 chrome 优化过的, 可以解决很多不规范问题)
+           页 html (该 html 是经过 chrome 优化过的, 可以解决很多不规范问题)
     IN: ifile. e.g. 'in.html'
     OT: ofile. e.g. 'out.xlsx'
     """
@@ -477,7 +477,7 @@ def _find_direct_parent_nodes(target, etree, holder):
         使用本方法 -> [e1, e3]
     
     FEATURE: 本方法支持忽略大小写. 例如 target = 'table', 则 <TABLE> 标签也可以
-    被查找到.
+        被查找到.
     ARGS:
         target (str): 目前仅支持 str 类型的 tag name, 例如 'table'
         etree: 初始化请传入 soup 或 master_element
@@ -548,11 +548,11 @@ def _get_row_values(rowsplug, merge, rowx, row):
 def _clean(v):
     """
     处理:
-    1. 删除换行符
-    2. 特殊字符变为空格
-    3. 去除前后空字符串
-    4. 对中文之间的空格删除, 例如 "张 三" 变成 "张三", 且保护英文的 "zhang san"
-    不会变成 "zhangsan"
+        1. 删除换行符
+        2. 特殊字符变为空格
+        3. 去除前后空字符串
+        4. 对中文之间的空格删除, 例如 "张 三" 变成 "张三", 且保护英文的
+           "zhang san" 不会变成 "zhangsan"
     """
     reg1 = re.compile(r'\n')  # '\n' -> ''
     reg2 = re.compile(r'\s+')  # '  ' -> ' '
