@@ -2,17 +2,26 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : excel_writer.py
 @Created : 2018-00-00
-@Updated : 2020-09-06
-@Version : 2.3.2
+@Updated : 2020-10-19
+@Version : 2.3.6
 @Desc    : ExcelWriter is a post-packing implementation based on XlsxWriter.
 """
-from os import path as ospath
 from typing import *
 from warnings import filterwarnings
 
+from xlsxwriter.format import Format as ExlFormat
+
 # shield Python 3.8 SyntaxWarning from XlsxWriter.
 filterwarnings('ignore', category=SyntaxWarning)
 
+# typing hints
+_CellFormat = ExlFormat
+_CellValue = Union[str, bool, int, float, None,]
+_ColValues = _RowValues = Iterable
+
+_ColsValues = List[_ColValues]
+_RowsValues = List[_RowValues]
+
 
 class ExcelWriter:
     """ ExcelWriter is an encapsulated implementation of xlsxwriter module,
@@ -84,7 +93,15 @@ class ExcelWriter:
             'valign': 'vcenter',
             # 'text_wrap': False,  # auto line wrap (default False)
         })  # REF: https://blog.csdn.net/lockey23/article/details/81004249
-    
+
+    def add_new_sheet(self, sheet_name=''):
+        self.sheetx += 1
+        self.rowx = -1
+        # create sheet name
+        if not sheet_name:
+            sheet_name = f'sheet {self.sheetx}'  # -> 'sheet 1', 'sheet 2', ...
+        self.sheet = self.book.add_worksheet(sheet_name)
+
     def __enter__(self):
         """ Return self to use with `with` statement.
         Use case: `with ExcelWriter(filepath) as writer: pass`.
@@ -98,17 +115,26 @@ class ExcelWriter:
         self.__h = 'parent'  # reset
     
     def save(self):
-        from lk_logger import lk
-        lk.logt('[ExcelWriter][I1139]', f'Excel saved to "{self.filepath}"',
+        from xlsxwriter.exceptions import FileCreateError
+        try:
+            self.book.close()
+        except FileCreateError:
+            if input('Permission denied on saving excel: \n'
+                     '\t\t{}\n'
+                     '\tPlease close the opened file manually and input "Y" to '
+                     'retry to save.'.format(self.filepath)).lower() == 'y':
+                self.book.close()
+            else:
+                raise FileCreateError
+        from .lk_logger import lk
+        lk.logt('[ExcelWriter][D1139]', f'Excel saved to "{self.filepath}"',
                 h=self.__h)
-        self.book.close()
     
     close = save
     
     # --------------------------------------------------------------------------
     
-    def write(self, rowx: int, colx: int,
-              data: Union[str, bool, int, float, None], fmt=None):
+    def write(self, rowx: int, colx: int, data: _CellValue, fmt=None):
         """ Write data to cell.
         
         :param rowx: int. Row number, starts from 0.
@@ -118,7 +144,8 @@ class ExcelWriter:
         """
         self.sheet.write(rowx, colx, data, fmt)
     
-    def writeln(self, *row, auto_index=False, purify_values=False, fmt=None):
+    def writeln(self, *row: _RowValues, auto_index=False, purify_values=False,
+                fmt=None):
         """ Write line of data to cells (with auto line breaks). """
         if purify_values:
             row = self.purify_values(row)
@@ -129,23 +156,25 @@ class ExcelWriter:
             self.sheet.write(self.rowx, 0, self.rowx, fmt)
             self.sheet.write_row(self.rowx, 1, row, fmt)
     
-    def writelnx(self, *row, fmt=None):
+    def writelnx(self, *row: _RowValues, fmt=None):
         self.writeln(*row, auto_index=True, fmt=fmt)
     
-    def writerow(self, rowx, data, offset=0, purify_values=False, fmt=None):
+    def writerow(self, rowx: int, data: _CellValue, offset=0,
+                 purify_values=False, fmt=None):
         """ Write row of data to cells. """
         if purify_values:
             data = self.purify_values(data)
         self.sheet.write_row(rowx, offset, data, fmt)
     
-    def writecol(self, colx, data, offset=0, purify_values=False, fmt=None):
+    def writecol(self, colx: int, data: _CellValue, offset=0,
+                 purify_values=False, fmt=None):
         """ Write column of data to cells. """
         if purify_values:
             data = self.purify_values(data)
         self.sheet.write_column(offset, colx, data, fmt)
     
     @staticmethod
-    def purify_values(row):
+    def purify_values(row: _RowValues):
         """
         Callers: self.writeln, self.writerow, self.writecol.
         """
@@ -159,7 +188,7 @@ class ExcelWriter:
     
     # --------------------------------------------------------------------------
     
-    def merging_visual(self, rows, to_left='<', to_up='^',
+    def merging_visual(self, rows: _RowValues, to_left='<', to_up='^',
                        offset=(0, 0), fmt=None):
         """ Merge cells in "visual" mode.
         Symbol: '<' means merged to the left cell, '^' merged to the upper cell.
@@ -233,27 +262,19 @@ class ExcelWriter:
                     cell, cell_format=fmt or self._merge_format
                 )
     
-    def merging_logical(self, point, span_x, span_y, value, fmt=None):
+    def merging_logical(self, p: Tuple[int, int], q: Tuple[int, int],
+                        value: _CellValue, fmt=None):
         """ Merge cells in "logical" mode.
-        TODO: Check legality of merging range (find if conflicts on overlapped
-            cells.)
+        
+        NOTE:
+            1. 本方法不检查传入的单元格范围是否有交叠或冲突
+            2. 注意 p 和 q 的坐标是 (rowx, colx), 也就是先定义第几行, 再定义第几
+               列
         """
+        if p == q:  # 如果要合并的单元格范围实际上只有一格, 则不要合并. 否则
+            #   xlsxwriter 会发出 "合并无效" 的警告.
+            return
         self.sheet.merge_range(
-            point[0], point[1], point[0] + span_x, point[1] + span_y,
+            p[0], p[1], q[0], q[1],
             value, cell_format=fmt or self._merge_format
         )
-    
-    # --------------------------------------------------------------------------
-    
-    def add_new_sheet(self, sheet_name='', prompt=False):
-        self.sheetx += 1
-        self.rowx = -1
-        # create sheet name
-        if not sheet_name:
-            sheet_name = f'sheet {self.sheetx}'  # -> 'sheet 1', 'sheet 2', ...
-        if prompt:
-            from lk_logger import lk
-            lk.logt('[ExcelWriter][D1344]',
-                    f'Add new sheet: "{sheet_name}" (sheetx {self.sheetx})',
-                    ospath.split(self.filepath)[1])
-        self.sheet = self.book.add_worksheet(sheet_name)
