@@ -1,3 +1,11 @@
+"""
+@Author  : Likianta <likianta@foxmail.com>
+@Module  : regex_helper.py
+@Created : 2019-06-24
+@Updated : 2019-11-12
+@Version : 1.0.2
+@Desc    :
+"""
 from re import compile
 
 digit_pattern = compile(r'\d+')
